@@ -1,7 +1,7 @@
 use crate::internal::*;
 
-mod deser;
-mod ser;
+pub mod deser;
+pub mod ser;
 
 pub fn tract_nnef() -> Registry {
     use tract_core::ops;
@@ -94,6 +94,7 @@ pub fn tract_nnef() -> Registry {
     primitive(&mut registry, "matmul", deser::matmul);
     dumper!(ops::matmul::MatMulUnary, ser::matmul_unary);
     dumper!(ops::matmul::MatMul, ser::matmul);
+    dumper!(ops::matmul::QMatMul, ser::qmatmul);
 
     primitive(&mut registry, "conv", deser::conv);
     dumper!(ops::cnn::ConvUnary, ser::conv);
